@@ -101,7 +101,9 @@ enum QtModule
     QtTextToSpeechModule      = 0x0000400000000000,
     QtSerialBusModule         = 0x0000800000000000,
     QtGamePadModule           = 0x0001000000000000,
-    Qt3DAnimationModule       = 0x0002000000000000
+    Qt3DAnimationModule       = 0x0002000000000000,
+    QtWebViewModule           = 0x0004000000000000,
+    Qt3DExtrasModule          = 0x0008000000000000
 };
 
 struct QtModuleEntry {
@@ -158,10 +160,12 @@ static QtModuleEntry qtModuleEntries[] = {
     { Qt3DQuickRendererModule, "3dquickrenderer", "Qt53DQuickRender", 0 },
     { Qt3DInputModule, "3dinput", "Qt53DInput", 0 },
     { Qt3DAnimationModule, "3danimation", "Qt53DAnimation", 0 },
+    { Qt3DExtrasModule, "3dextras", "Qt53DExtras", 0 },
     { QtLocationModule, "geoservices", "Qt5Location", 0 },
     { QtWebChannelModule, "webchannel", "Qt5WebChannel", 0 },
     { QtTextToSpeechModule, "texttospeech", "Qt5TextToSpeech", 0 },
-    { QtSerialBusModule, "serialbus", "Qt5SerialBus", 0 }
+    { QtSerialBusModule, "serialbus", "Qt5SerialBus", 0 },
+    { QtWebViewModule, "webview", "Qt5WebView", 0 }
 };
 
 static const char webKitProcessC[] = "QtWebProcess";
@@ -192,7 +196,7 @@ static Platform platformFromMkSpec(const QString &xSpec)
     if (xSpec == QLatin1String("linux-g++"))
         return Unix;
     if (xSpec.startsWith(QLatin1String("win32-")))
-        return xSpec.contains(QLatin1String("g++")) ? WindowsMinGW : Windows;
+        return xSpec.contains(QLatin1String("g++")) ? WindowsDesktopMinGW : WindowsDesktop;
     if (xSpec.startsWith(QLatin1String("winrt-x")))
         return WinRtIntel;
     if (xSpec.startsWith(QLatin1String("winrt-arm")))
@@ -253,7 +257,7 @@ struct Options {
     bool compilerRunTime = false;
     AngleDetection angleDetection = AngleDetectionAuto;
     bool softwareRasterizer = true;
-    Platform platform = Windows;
+    Platform platform = WindowsDesktop;
     quint64 additionalLibraries = 0;
     quint64 disabledLibraries = 0;
     unsigned updateFileFlags = 0;
@@ -433,7 +437,7 @@ static inline int parseArguments(const QStringList &arguments, QCommandLineParse
     parser->addOption(listOption);
 
     QCommandLineOption verboseOption(QStringLiteral("verbose"),
-                                     QStringLiteral("Verbose level."),
+                                     QStringLiteral("Verbose level (0-2)."),
                                      QStringLiteral("level"));
     parser->addOption(verboseOption);
 
@@ -479,7 +483,7 @@ static inline int parseArguments(const QStringList &arguments, QCommandLineParse
     else if (parser->isSet(noCompilerRunTimeOption))
         options->compilerRunTime = false;
 
-    if (options->compilerRunTime && options->platform != WindowsMinGW && options->platform != Windows) {
+    if (options->compilerRunTime && options->platform != WindowsDesktopMinGW && options->platform != WindowsDesktop) {
         *errorMessage = QStringLiteral("Deployment of the compiler runtime is implemented for Desktop only.");
         return CommandLineParseError;
     }
@@ -666,13 +670,11 @@ static inline QString helpText(const QCommandLineParser &p)
 
 static inline bool isQtModule(const QString &libName)
 {
-    // Match Standard modules, Qt5XX.dll, Qt[Commercial]Charts.dll and special cases.
-    return libName.size() > 2
-        && ((libName.startsWith(QLatin1String("Qt"), Qt::CaseInsensitive) && libName.at(2).isDigit())
-            || libName.startsWith(QLatin1String("QtCommercial"), Qt::CaseInsensitive)
-            || libName.startsWith(QLatin1String("QtCharts"), Qt::CaseInsensitive)
-            || libName.startsWith(QLatin1String("DataVisualization"), Qt::CaseInsensitive)
-            || libName.startsWith(QLatin1String("Enginio"), Qt::CaseInsensitive));
+    // Match Standard modules named Qt5XX.dll
+    if (libName.size() < 3 || !libName.startsWith(QLatin1String("Qt"), Qt::CaseInsensitive))
+        return false;
+    const QChar version = libName.at(2);
+    return version.isDigit() && (version.toLatin1() - '0') == QT_VERSION_MAJOR;
 }
 
 // Helper for recursively finding all dependent Qt libraries.
@@ -821,7 +823,8 @@ static const PluginModuleMapping pluginModuleMappings[] =
     {"styles", QtWidgetsModule},
     {"sceneparsers", Qt3DRendererModule},
     {"renderplugins", Qt3DRendererModule},
-    {"geometryloaders", Qt3DRendererModule}
+    {"geometryloaders", Qt3DRendererModule},
+    {"webview", QtWebViewModule}
 };
 
 static inline quint64 qtModuleForPlugin(const QString &subDirName)
@@ -886,8 +889,8 @@ QStringList findQtPlugins(quint64 *usedQtModules, quint64 disabledQtModules,
             const bool isPlatformPlugin = subDirName == QLatin1String("platforms");
             if (isPlatformPlugin) {
                 switch (platform) {
-                case Windows:
-                case WindowsMinGW:
+                case WindowsDesktop:
+                case WindowsDesktopMinGW:
                 case WinCEIntel:
                 case WinCEArm:
                     filter = QStringLiteral("qwindows");
@@ -1081,7 +1084,7 @@ static QStringList compilerRunTimeLibs(Platform platform, bool isDebug, unsigned
 {
     QStringList result;
     switch (platform) {
-    case WindowsMinGW: { // MinGW: Add runtime libraries
+    case WindowsDesktopMinGW: { // MinGW: Add runtime libraries
         static const char *minGwRuntimes[] = {"*gcc_", "*stdc++", "*winpthread"};
         const QString gcc = findInPath(QStringLiteral("g++.exe"));
         if (gcc.isEmpty()) {
@@ -1099,7 +1102,7 @@ static QStringList compilerRunTimeLibs(Platform platform, bool isDebug, unsigned
                 result.append(dllFi.absoluteFilePath());
     }
         break;
-    case Windows: { // MSVC/Desktop: Add redistributable packages.
+    case WindowsDesktop: { // MSVC/Desktop: Add redistributable packages.
         QString vcRedistDirName = vcRedistDir();
         if (vcRedistDirName.isEmpty())
              break;
@@ -1173,7 +1176,7 @@ static bool updateLibrary(const QString &sourceFileName, const QString &targetDi
     if (options.deployPdb) {
         const QFileInfo pdb(pdbFileName(sourceFileName));
         if (pdb.isFile())
-            return updateFile(pdb.absoluteFilePath(), targetDirectory, options.updateFileFlags, Q_NULLPTR, errorMessage);
+            return updateFile(pdb.absoluteFilePath(), targetDirectory, options.updateFileFlags, nullptr, errorMessage);
     }
     return true;
 }
@@ -1223,7 +1226,7 @@ static DeployResult deploy(const Options &options,
     }
     for (int b = 1; b < options.binaries.size(); ++b) {
         if (!findDependentQtLibraries(libraryLocation, options.binaries.at(b), options.platform, errorMessage, &dependentQtLibs,
-                                      Q_NULLPTR, Q_NULLPTR, Q_NULLPTR)) {
+                                      nullptr, nullptr, nullptr)) {
             return result;
         }
     }
@@ -1641,7 +1644,7 @@ int main(int argc, char **argv)
     const QMap<QString, QString> qmakeVariables = queryQMakeAll(&errorMessage);
     const QString xSpec = qmakeVariables.value(QStringLiteral("QMAKE_XSPEC"));
     options.platform = platformFromMkSpec(xSpec);
-    if (options.platform == WindowsMinGW || options.platform == Windows)
+    if (options.platform == WindowsDesktopMinGW || options.platform == WindowsDesktop)
         options.compilerRunTime = true;
 
     {   // Command line
